@@ -92,7 +92,7 @@ assign("options", list(
                       itol=1e-16,
                       cluster.index=versioncheck("mets",c(0,2,7)),
                       tobit=versioncheck("lava.tobit",c(0,5)),
-                      Dmethod="simple", ##"Richardson"
+                      Dmethod="simple",
                       messages=ifelse(interactive(), 1, 0),
                       parallel=TRUE,
                       param="relative",
