@@ -12,17 +12,19 @@
 ##' @keywords utilities misc
 ##' @seealso \code{blockdiag}, \code{\link{paste}}, \code{\link{cat}},
 ##' @examples
+##' ## Block diagonal
 ##' matrix(rnorm(25),5)%++%matrix(rnorm(25),5)
+##' ## String concatenation
 ##' "Hello "%++%" World"
+##' ## Function composition
+##' f <- log %++% exp
+##' f(2)
 ##' @export
 `%++%` <- function(x,y) UseMethod("%++%",y)
 
 ## ##' @export
 ## `%+%` <- function(x,y) UseMethod("%+%",y)
 
-##' @export
-`%++%.default` <- function(x,y) x%++%y
-
 ##' @export
 `%++%.default` <- function(x,y) paste0(x,y)
 
@@ -32,6 +34,9 @@
 ##' @export
 `%++%.matrix` <- function(x,y) blockdiag(x,y)
 
+##' @export
+`%++%.function` <- function(x,y) function(...) x(y(...))
+
 
 notin <- Negate(get("%in%"))
 ##' Matching operator (x not in y) oposed to the \code{\%in\%}-operator (x in y)
